%pathfinder.m
%refinament of constrained.m  that avoids debt choices  that  lead with 
%positive probability to areas of the state  space for whicheither consumption is 
%nonpositive or  the aggregate collateral constraint is violated in the 
%future. 
% Martn Uribe and Stephanie Schmitt-Groh, 2016.

function Ztry = pathfinder(dupper, dlower, nd, rstar, betta, a, yN,xi, sigg, kapa)

load annual_tpm.mat pai ygrid rgrid; %produced by running 
%annual_tpm.m
%in
%z:\joint\macroprudential\rshocks

ny = numel(ygrid); %number of grid points for the joint process of tradable output and  the country interest rate (yT,r)

yTgridlevel = exp(ygrid(:)); %grid of level of tradable output
rgridlevel = exp(rgrid)*(1+rstar)-1; %grid of level of country interest rate

NdL = min(yTgridlevel)*(1+max(rgridlevel))/max(rgridlevel); %natural debt limit

tarpi = 1;

n = ny*nd; %total number of states

%Let yT, r, and d  be 3 ny-by-nd matrices containing values  of the current state
yT = repmat(yTgridlevel,1,nd);  
r = repmat(rgridlevel,1,nd);  

%debt grid
dgrid = linspace(dlower,dupper,nd)';
dd = dgrid(2) - dgrid(1);

d = repmat(dgrid',ny,1);

dix = repmat(1:nd,ny,1); %ny-by-nd matrix of indices of the current debt state

%n-by-nd matrix of tradable consumption as a function of the current state (n in total) and  possible choices of next-period debt (nd in total)
bsxfun(@rdivide,dgrid',1+r(:));
cTtry = bsxfun(@plus,ans,yT(:)-d(:));

if min(max(cTtry,[],2))<=0
error('Natural debt limit violated')
end

%n-by-nd matrix of relative price of nontradables as a function of the current state (n in total) and possible values for next-period debt (nd in total)
ptry  = (1-a)/a*(cTtry/yN).^(1/xi);

%n-by-nd matrix of the value of collateral  as a function of the current state (n in total) and possible values for next-period debt (nd in total)
collateraltry = kapa*bsxfun(@plus,yT(:),yN*ptry);

%n-by-nd matrix of the slackness of the collateral constraint  as a function of the current state (n in total) and possible values for next-period debt (nd in total). 
slacktry = bsxfun(@minus,collateraltry,dgrid');

%Gridize  values of  slacktry matrix for   which the collateral constraint is binding  by setting them equal to 0
aux1 = sign(slacktry);
aux2 = sign([slacktry(:,1) slacktry(:,1:end-1)]);
aux3 = sign([ slacktry(:,2:end) slacktry(:,end)]);
slacktry1=slacktry; 
slacktry(aux1.*aux2==-1 & slacktry1<0) = 0;
slacktry(aux1.*aux3==-1 & slacktry1<0) = 0;
clear slacktry1;

%Correct for the possibility that for some current states there may be no choice of next-period debt for which cT is positive and the collateral constraint is satisfied. 
%
%First, identify the states (tarpi) for which this situation occurs
(cTtry<=0) | (slacktry<0);
sum(ans,2)==nd;
tarpi = find(ans);

TARP = zeros(ny,nd);
TARP(tarpi) = 1;
X = repmat(pai>0,nd,1);
Ztry = NaN(n,nd);
for i=1:nd
Y = repmat(TARP(:,i)',n,1);
Y = Y.*X;
Y = sum(Y,2);
find(Y==0);
Ztry(ans,i) = 1;
i
end