%typical_boom_bust.m plots equilibrium dynamics during a boom-bust cycle in  the unregulated and Ramsey   two-sector small open economies driven by interest-rate and tradablel-endowment shocks  
%with a flow collateral constraint  presented in the paper 
%``Is Optimal Capital-Control Policy Countercyclical In Open-Economy  Models With Collateral Constraints?'' by Stephanie Schmitt-Groh and Martn Uribe, July 2016. 
%  Stephanie Schmitt-Groh and Martn Uribe, July 2016.

clear all
clf

%The unregulated economy with equilibrium selection criterion (c) 
load simu_constrained_c P YT Y CT Dp TB R kapa TAU yTgridlevel CA
%produced by running simu('constrained_c') in
%z:\joint\macroprudential\rshocks

X = lagg(YT,6);

uy=unique(yTgridlevel); 

%As in the boom bust cycle of the capital controls chapter of OEM, we associate 1
%std above the mean with uy(14) = 1.12 and one std below the mean with
%uy(8)= 0.89.  (uy(7) = 0.8570 which is too small). 
s1 = find( X(:,7)<=1 & X(:,4)>=uy(14)  & X(:,1)<=uy(8));

s1 = s1 + 6; 

ww = 6;

find(s1<=ww|s1>=length(Y)-ww);
s1 = setdiff(s1,s1(ans));


nw = numel(s1);

WP1 = zeros(nw,2*ww+1);
WYT1 = zeros(nw,2*ww+1);
WY1 = zeros(nw,2*ww+1);
WCT1 = zeros(nw,2*ww+1);
WCA1 = zeros(nw,2*ww+1);
WD1 = zeros(nw,2*ww+1);
WTB1 = zeros(nw,2*ww+1);
WR1 = zeros(nw,2*ww+1);
Wcollateral = zeros(nw,2*ww+1);
WDpY1 = zeros(nw,2*ww+1);

for i=1:nw
WP1(i,:) = P(s1(i)-ww:s1(i)+ww)';
WYT1(i,:) = YT(s1(i)-ww:s1(i)+ww)';
WY1(i,:) = Y(s1(i)-ww:s1(i)+ww)';
WCT1(i,:) = CT(s1(i)-ww:s1(i)+ww)';
WCA1(i,:) = CA(s1(i)-ww:s1(i)+ww)';
WD1(i,:) = Dp(s1(i)-ww:s1(i)+ww)';
WTB1(i,:) = TB(s1(i)-ww:s1(i)+ww)';
WR1(i,:) = R(s1(i)-ww:s1(i)+ww)';
Wcollateral(i,:) = Y(s1(i)-ww:s1(i)+ww)' * kapa ;
WDpY1(i,:) =  Dp(s1(i)-ww:s1(i)+ww)'./Y(s1(i)-ww:s1(i)+ww)';
end
thick = 2;

WSLACK1 = Wcollateral-WD1;
orient tall, rows = 4;
cols=2; 
%for slides: cols = 4;orient portrait


subplot(rows,cols,1)
x =  mean(WYT1);
plot(-ww:ww,x,'linewidth',thick);
title('Traded Endowment')
xlim([-ww ww])
hold on

f=@mean
x =  f(WR1);
subplot(rows,cols,2)
plot(-ww:ww,x,'linewidth',thick);
title('Interest Rate')
xlim([-ww ww])
hold on

subplot(rows,cols,3)
x =  f(WY1);
plot(-ww:ww,x,'linewidth',thick);
title('Output')
xlim([-ww ww])
hold on

x =  f(WCT1);
subplot(rows,cols,4)
plot(-ww:ww,x,'linewidth',thick);
title('Consumption of Tradables')
xlim([-ww ww])
hold on

x = f(WP1);
subplot(rows,cols,5)
plot(-ww:ww,x,'linewidth',thick);
title('Relative Price of Nontradables')
xlim([-ww ww])
hold on

if 1<2
x =  f(WD1);
subplot(rows,cols,6)
plot(-ww:ww,x,'linewidth',thick);
title('Debt and Collateral')
xlim([-ww ww])
hold on
x = f(Wcollateral);
plot(-ww:ww,x, 'linewidth',1);
else
    hold off
x =  mean(WDpY1);
subplot(rows,cols,6)
plot(-ww:ww,x,'linewidth',thick);
title('Debt to Output Ratio')
xlim([-ww ww])
hold on
end

x =  f(WTB1);
subplot(rows,cols,7)
plot(-ww:ww,x,'linewidth',thick);
title('Trade Balance')
xlim([-ww ww])
hold on


clear all

%Ramsey optimal capital control policy: 


load simu_ramsey  P YT Y CT Dp TB R kapa TAU yTgridlevel CA CRISIS
%produced by running simu('ramsey') in
%Z:\joint\macroprudential\rshocks
%the program simu.m loads ramsey.mat, which in turn is produced by running ramsey.m 


TAU(CRISIS==1) = NaN; 


X = lagg(YT,6);

uy=unique(yTgridlevel); 
%As in the boom bust cycle of the capital controls chapter of OEM, we associate 1
%std above the mean with uy(14) = 1.12 and one std below the mean with
%uy(8)= 0.89.  (uy(7) = 0.8570 which is too small). 
s1 = find( X(:,7)<=1 & X(:,4)>=uy(14)  & X(:,1)<=uy(8));

s1 = s1 + 6; 

ww = 6;

find(s1<=ww|s1>=length(Y)-ww);

s1 = setdiff(s1,s1(ans));

nw = numel(s1);

WP1 = zeros(nw,2*ww+1);
WYT1 = zeros(nw,2*ww+1);
WY1 = zeros(nw,2*ww+1);
WCT1 = zeros(nw,2*ww+1);
WCA1 = zeros(nw,2*ww+1);
WD1 = zeros(nw,2*ww+1);
WDp1 = zeros(nw,2*ww+1);
WTB1 = zeros(nw,2*ww+1);
WR1 = zeros(nw,2*ww+1);
Wcollateral = zeros(nw,2*ww+1);
WTAU1 = zeros(nw, 2*ww+1); 
WDpY1 = zeros(nw,2*ww+1);


for i=1:nw
WP1(i,:) = P(s1(i)-ww:s1(i)+ww)';
WYT1(i,:) = YT(s1(i)-ww:s1(i)+ww)';
WY1(i,:) = Y(s1(i)-ww:s1(i)+ww)';
WCT1(i,:) = CT(s1(i)-ww:s1(i)+ww)';
WCA1(i,:) = CA(s1(i)-ww:s1(i)+ww)';
WD1(i,:) = Dp(s1(i)-ww:s1(i)+ww)';
WTB1(i,:) = TB(s1(i)-ww:s1(i)+ww)';
WR1(i,:) = R(s1(i)-ww:s1(i)+ww)';
Wcollateral(i,:) = Y(s1(i)-ww:s1(i)+ww)' * kapa ;
WTAU1(i,:) = TAU(s1(i)-ww:s1(i)+ww)';
WDpY1(i,:) = Dp(s1(i)-ww:s1(i)+ww)'./Y(s1(i)-ww:s1(i)+ww)';
end

thick = 2;

WSLACK1 = Wcollateral-WD1;
rows = 4;
cols=2;
%for slides: cols = 4 
LT='--'; 

f=@mean
subplot(rows,cols,1)
x = f(WYT1);
plot(-ww:ww,x,LT,'linewidth',thick);
title('Traded Output')
xlim([-ww ww])
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
ylim([0.85 1.15])

x =  f(WR1);
subplot(rows,cols,2)
plot(-ww:ww,x,LT,'linewidth',thick);
xlim([-ww ww])
ylim([0.05 0.25])
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')

x =  f(WY1);
subplot(rows,cols,3)
plot(-ww:ww,x,LT,'linewidth',thick);
title('Output')
xlim([-ww ww])
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')

x =  f(WCT1);
subplot(rows,cols,4)
plot(-ww:ww,x,LT,'linewidth',thick);
title('Consumption of Tradables')
xlim([-ww ww])
axis('tight')
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])

x =  f(WP1);
subplot(rows,cols,5)
plot(-ww:ww,x,LT,'linewidth',thick);
title('Relative Price of Nontradables')
xlim([-ww ww])
ylim([1 3.5]); 
v=ylim(gca)
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')

if 1<2
x =  f(WD1);
subplot(rows,cols,6)
plot(-ww:ww,x,LT,'linewidth',thick);
xlim([-ww ww])
x =  f(Wcollateral);
plot(-ww:ww,x,LT, 'linewidth',1);
else
x =  f(WDpY1);
subplot(rows,cols,6)
plot(-ww:ww,x,LT,'linewidth',thick);
end
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')

x =  f(WTB1);
subplot(rows,cols,7)
plot(-ww:ww,x,LT,'linewidth',thick);
title('Trade Balance')
xlim([-ww ww])
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')

if 1<2
    x = 100* nanmedian(WTAU1);

h=subplot(rows,cols,8)
plot(-ww:ww,x,LT,'linewidth',thick);
title('Capital Control Tax, in percent')
set(h, 'XTick', [-5 -2 0 5])
xlim([-ww ww])
hold on
v=ylim(gca); 
plot(-3*[1 1],v, ':') 
plot(0*[1 1],v, ':') 
set(gca, 'XTick', [-6 -3 0 3 6])
axis('tight')
end
hold off
shg