%typical_crisis.m plots equilibrium dynamics during a typical financial crisis (defined as an episode in which the collateral constrain binds)  implied by the 
% unregulated and Ramsey   two-sector small open  economy 
%with a flow collateral constraint driven by interest-rate and tradable-endowment shocks  in the paper
%``Is Optimal Capital-Control Policy Countercyclical In Open-Economy  Models With Collateral Constraints?'' by Stephanie Schmitt-Groh and Martn Uribe, July 2016. 
%  Stephanie Schmitt-Groh and Martn Uribe, July 2016.
clear all
clf

orient tall; rows = 4;cols=2; 
%slides : 
%orient portrait, rows = 3, cols = 4; 

load simu_constrained_c  CRISIS Y P YT CT  Dp TB SLACK  kapa R
%produced by running simu('constrained_c')
%In turn, the file constrained.mat is produced by running constrained.m and setting eqm_selection_criterion = 'c';
%all aforementioned files are in 
%z:\joint\macroprudential\rshocks

ww = 5; 

s1 = find(CRISIS==1);

find(s1<=ww|s1>=length(Y)-ww);
s1 = setdiff(s1,s1(ans));
nw = numel(s1);
save s1.mat s1 

WP1 = zeros(nw,2*ww+1);
WYT1 = zeros(nw,2*ww+1);
WY1 = zeros(nw,2*ww+1);
WCT1 = zeros(nw,2*ww+1);
WD1 = zeros(nw,2*ww+1);
WTB1 = zeros(nw,2*ww+1);
WR1 = zeros(nw,2*ww+1);
WSLACK1 = zeros(nw,2*ww+1);
WDp1 = zeros(nw,2*ww+1);
WDpY1 = zeros(nw,2*ww+1);


for i=1:nw
WP1(i,:) = P(s1(i)-ww:s1(i)+ww)';
WYT1(i,:) = YT(s1(i)-ww:s1(i)+ww)';
WY1(i,:) = Y(s1(i)-ww:s1(i)+ww)';
WCT1(i,:) = CT(s1(i)-ww:s1(i)+ww)';
WD1(i,:) = Dp(s1(i)-ww:s1(i)+ww)';
WTB1(i,:) = TB(s1(i)-ww:s1(i)+ww)';
WSLACK1(i,:) = SLACK(s1(i)-ww:s1(i)+ww)';
WR1(i,:) = R(s1(i)-ww:s1(i)+ww)';
WDpY1(i,:) = Dp(s1(i)-ww:s1(i)+ww)'./Y(s1(i)-ww:s1(i)+ww)';

end
thick = 2;

Wcollateral = WSLACK1+WD1;

f=@mean

x =  f(WYT1);
subplot(rows,cols,1)
plot(-ww:ww,x,'linewidth',thick);
title('Traded Endowment')
xlim([-ww ww])
hold on

x =  f(WR1);
subplot(rows,cols,2)
plot(-ww:ww,x,'linewidth',thick);
title('Interest Rate')
xlim([-ww ww])
hold on

x =  f(WY1);
subplot(rows,cols,3)
plot(-ww:ww,x,'linewidth',thick);
title('Output')
xlim([-ww ww])
hold on

x =  f(WCT1);
subplot(rows,cols,4)
plot(-ww:ww,x,'linewidth',thick);
title('Consumption of Tradables')
xlim([-ww ww])
hold on

x =  f(WP1);
subplot(rows,cols,5)
plot(-ww:ww,x,'linewidth',thick);
title('Relative Price of Nontradables')
xlim([-ww ww])
hold on

x =  f(WD1);
subplot(rows,cols,6)
plot(-ww:ww,x,'linewidth',thick);
title('Debt and Collateral')
xlim([-ww ww])
hold on
x =  f(Wcollateral);
plot(-ww:ww,x,'linewidth',1);

x =  f(WTB1);
subplot(rows,cols,7)
plot(-ww:ww,x,'linewidth',thick);
title('Trade Balance')
xlim([-ww ww])
hold on

clear all
load simu_ramsey P YT Y CT  Dp TB R TAU SLACK CRISIS
%produced by running simu('ramsey') 
%In turn, the file ramsey.mat is produced by running ramsey.m 
%all files are located in
%z:\joint\macroprudential\mfiles_bianchi

TAU(CRISIS==1) = NaN; 

ww = 5;

load s1.mat s1

nw = numel(s1);


WP1 = zeros(nw,2*ww+1);
WYT1 = zeros(nw,2*ww+1);
WY1 = zeros(nw,2*ww+1);
WCT1 = zeros(nw,2*ww+1);
WD1 = zeros(nw,2*ww+1);
WTB1 = zeros(nw,2*ww+1);
WR1 = zeros(nw,2*ww+1);
WTAU1 = zeros(nw,2*ww+1);
WSLACK1 = zeros(nw,2*ww+1);
WDpY1 = zeros(nw,2*ww+1);


for i=1:nw
WP1(i,:) = P(s1(i)-ww:s1(i)+ww)';
WYT1(i,:) = YT(s1(i)-ww:s1(i)+ww)';
WY1(i,:) = Y(s1(i)-ww:s1(i)+ww)';
WCT1(i,:) = CT(s1(i)-ww:s1(i)+ww)';
WD1(i,:) = Dp(s1(i)-ww:s1(i)+ww)';
WTB1(i,:) = TB(s1(i)-ww:s1(i)+ww)';
WR1(i,:) = R(s1(i)-ww:s1(i)+ww)';
WTAU1(i,:) = TAU(s1(i)-ww:s1(i)+ww)';
WSLACK1(i,:) = SLACK(s1(i)-ww:s1(i)+ww)';
WDpY1(i,:) = Dp(s1(i)-ww:s1(i)+ww)'./Y(s1(i)-ww:s1(i)+ww)';

end

LT = '--';
orient tall; rows = 4;cols=2; 
%orient portrait, rows = 3, cols = 4; 
thick = 2;

Wcollateral = WSLACK1+WD1;

f=@mean

x =  f(WYT1);
subplot(rows,cols,1)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  f(WR1);
subplot(rows,cols,2)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  f(WY1);
subplot(rows,cols,3)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  f(WCT1);
subplot(rows,cols,4)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  f(WP1);
subplot(rows,cols,5)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  f(WD1);
subplot(rows,cols,6)
plot(-ww:ww,x, LT, 'linewidth',thick);
x =  f(Wcollateral);
plot(-ww:ww,x,LT,'linewidth',1);
axis('tight')

x =  f(WTB1);
subplot(rows,cols,7)
plot(-ww:ww,x,LT,'linewidth',thick);
axis('tight')

x =  nanmedian(WTAU1);
subplot(rows,cols,8)
plot(-ww:ww,100*x,LT,'linewidth',thick);
title('Capital Control Tax, in percent')
axis('tight')


shg